==> haskell-hakyll-4.13.0.1-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hakyll.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hakyll
version:              4.13.0.1
visibility:           public
id:                   hakyll-4.13.0.1-Id0GPhRif291v0QluLDCJT
key:                  hakyll-4.13.0.1-Id0GPhRif291v0QluLDCJT
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             http://jaspervdj.be/hakyll
synopsis:             A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:

    * <http://jaspervdj.be/hakyll>

    If you seek assistance, there'\''s:

    * A google group: <http://groups.google.com/group/hakyll>

    * An IRC channel, @#hakyll@ on freenode

    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.

category:             Web
abi:                  8080becd3d828f9437f1f653df53d22d
exposed:              True
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Compiler.Internal Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item Hakyll.Core.Logger
    Hakyll.Core.Metadata Hakyll.Core.Provider
    Hakyll.Core.Provider.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.Rules.Internal Hakyll.Core.Runtime Hakyll.Core.Store
    Hakyll.Core.UnixFilter Hakyll.Core.Util.File
    Hakyll.Core.Util.String Hakyll.Core.Writable Hakyll.Main
    Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Paginate
    Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List

hidden-modules:
    Data.List.Extended Data.Yaml.Extended Hakyll.Check
    Hakyll.Core.Compiler.Require
    Hakyll.Core.Identifier.Pattern.Internal Hakyll.Core.Item.SomeItem
    Hakyll.Core.Provider.Internal Hakyll.Core.Provider.MetadataCache
    Hakyll.Core.Util.Parser Paths_hakyll Hakyll.Preview.Poll
    Hakyll.Preview.Server Hakyll.Web.Pandoc.Binary

import-dirs:          /usr/lib/ghc-8.8.3/site-local/hakyll-4.13.0.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/hakyll-4.13.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hakyll
hs-libraries:         HShakyll-4.13.0.1-Id0GPhRif291v0QluLDCJT
depends:
    base-4.13.0.0 binary-0.8.7.0
    blaze-html-0.9.1.2-4RtyBwX2BF447DinRsQS92
    blaze-markup-0.8.2.3-p32oAP7imXDQCSuK8yXLb bytestring-0.10.10.0
    containers-0.6.2.1 cryptohash-0.11.9-9cNidGoRvjXJcyRb0Qj65g
    data-default-0.7.1.1-EftUPu9UviH5yKWklJYX5z deepseq-1.4.4.0
    directory-1.3.6.0 file-embed-0.0.11.2-76jJzrpjGcdDpzOtgwH8dS
    filepath-1.4.2.1 fsnotify-0.3.0.1-KlllLpqOP8M6dSErvan8Uk
    http-conduit-2.3.7.3-E1JBPq9fABvHCpQXuTdMMS
    http-types-0.12.3-5BPAUxC0m6vK6wLu4ahmic
    lrucache-1.2.0.1-8CJdEajSSMA5joHNfryPAW mtl-2.2.2
    network-uri-2.6.3.0-JVIm6o5S7Mi9WmUDAeqPPz
    optparse-applicative-0.15.1.0-An71inc1YsbDQpJMiwk4K7
    pandoc-2.9.2-BufPYaykkg954zbZ3KpH6i
    pandoc-citeproc-0.17-GepKw75YQiVJmFdjLLKHzH parsec-3.1.14.0
    process-1.6.8.0 random-1.1-CUqV1zxrwrE4K5XCdTZSYy
    regex-tdfa-1.3.1.0-2thRUVc0Ew7ZsITrBIZey
    resourcet-1.2.3-BVDvrbFr17W7LvRilqTO58
    scientific-0.3.6.2-6irdu2VdjjMJDmbJHneA4J
    tagsoup-0.14.8-1cLX0ivkzkm9cUKskqLN3Z template-haskell-2.15.0.0
    text-1.2.4.0 time-1.9.3
    time-locale-compat-0.1.1.5-6zntZXPahUaLWVI6yBz8vC
    unordered-containers-0.2.10.0-1E0nFKYS8XWLVv5PGwMT0V
    vector-0.12.1.2-C2W44iPdAFeHo4yLU081Gd
    wai-3.2.2.1-BjkFMYvSQAYLPgbixmVO2f
    wai-app-static-3.1.7.1-5RzeHcFNOQ45RpzXn2w6M5
    warp-3.3.8-HAILknkEPShFHdTYkDxL9Q
    yaml-0.11.2.0-29W5l9zpAcrA4eSWWbVa4C

haddock-interfaces:   /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html:         /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hakyll-4.13.0.1-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hakyll.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hakyll
version:              4.13.0.1
visibility:           public
id:                   hakyll-4.13.0.1-Aqs1C08w0kND73pznb2DRq
key:                  hakyll-4.13.0.1-Aqs1C08w0kND73pznb2DRq
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             http://jaspervdj.be/hakyll
synopsis:             A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:

    * <http://jaspervdj.be/hakyll>

    If you seek assistance, there'\''s:

    * A google group: <http://groups.google.com/group/hakyll>

    * An IRC channel, @#hakyll@ on freenode

    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.

category:             Web
abi:                  e903496b9b8008255235e35ad211a9bb
exposed:              True
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Compiler.Internal Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item Hakyll.Core.Logger
    Hakyll.Core.Metadata Hakyll.Core.Provider
    Hakyll.Core.Provider.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.Rules.Internal Hakyll.Core.Runtime Hakyll.Core.Store
    Hakyll.Core.UnixFilter Hakyll.Core.Util.File
    Hakyll.Core.Util.String Hakyll.Core.Writable Hakyll.Main
    Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Paginate
    Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List

hidden-modules:
    Data.List.Extended Data.Yaml.Extended Hakyll.Check
    Hakyll.Core.Compiler.Require
    Hakyll.Core.Identifier.Pattern.Internal Hakyll.Core.Item.SomeItem
    Hakyll.Core.Provider.Internal Hakyll.Core.Provider.MetadataCache
    Hakyll.Core.Util.Parser Paths_hakyll Hakyll.Preview.Poll
    Hakyll.Preview.Server Hakyll.Web.Pandoc.Binary

import-dirs:          /usr/lib/ghc-8.8.3/site-local/hakyll-4.13.0.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/hakyll-4.13.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hakyll
hs-libraries:         HShakyll-4.13.0.1-Aqs1C08w0kND73pznb2DRq
depends:
    base-4.13.0.0 binary-0.8.7.0
    blaze-html-0.9.1.2-4RtyBwX2BF447DinRsQS92
    blaze-markup-0.8.2.3-p32oAP7imXDQCSuK8yXLb bytestring-0.10.10.0
    containers-0.6.2.1 cryptohash-0.11.9-9cNidGoRvjXJcyRb0Qj65g
    data-default-0.7.1.1-EftUPu9UviH5yKWklJYX5z deepseq-1.4.4.0
    directory-1.3.6.0 file-embed-0.0.11.2-76jJzrpjGcdDpzOtgwH8dS
    filepath-1.4.2.1 fsnotify-0.3.0.1-KlllLpqOP8M6dSErvan8Uk
    http-conduit-2.3.7.3-E1JBPq9fABvHCpQXuTdMMS
    http-types-0.12.3-5BPAUxC0m6vK6wLu4ahmic
    lrucache-1.2.0.1-8CJdEajSSMA5joHNfryPAW mtl-2.2.2
    network-uri-2.6.3.0-JVIm6o5S7Mi9WmUDAeqPPz
    optparse-applicative-0.15.1.0-An71inc1YsbDQpJMiwk4K7
    pandoc-2.9.2-KqdeiTT3AKQ687x0G7Wqdx
    pandoc-citeproc-0.17-3XFLNWu3uO6AVPc8WBaFR2 parsec-3.1.14.0
    process-1.6.8.0 random-1.1-CUqV1zxrwrE4K5XCdTZSYy
    regex-tdfa-1.3.1.0-2thRUVc0Ew7ZsITrBIZey
    resourcet-1.2.3-BVDvrbFr17W7LvRilqTO58
    scientific-0.3.6.2-6irdu2VdjjMJDmbJHneA4J
    tagsoup-0.14.8-1cLX0ivkzkm9cUKskqLN3Z template-haskell-2.15.0.0
    text-1.2.4.0 time-1.9.3
    time-locale-compat-0.1.1.5-6zntZXPahUaLWVI6yBz8vC
    unordered-containers-0.2.10.0-1E0nFKYS8XWLVv5PGwMT0V
    vector-0.12.1.2-C2W44iPdAFeHo4yLU081Gd
    wai-3.2.2.1-BjkFMYvSQAYLPgbixmVO2f
    wai-app-static-3.1.7.1-5RzeHcFNOQ45RpzXn2w6M5
    warp-3.3.8-HAILknkEPShFHdTYkDxL9Q
    yaml-0.11.2.0-29W5l9zpAcrA4eSWWbVa4C

haddock-interfaces:   /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html:         /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
